@@ -6,18 +6,12 @@ OC.L10N.register(
     "No server to federate with found" : "Geen server gevonden om mee te federeren",
     "Could not add server" : "Kon server niet toevoegen",
     "Federation" : "Federatie",
+    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federatie maakt het mogelijk om te verbinden met andere vertrouwde servers om de gebuikersadministratie te delen.",
     "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federatie maakt het mogelijk om te verbinden met vertrouwde servers en de gebuikersadministratie te delen. Zo kun je automatisch externe gebruikers toevoegen voor federatief delen.",
-    "Add server automatically once a federated share was created successfully" : "Voeg server automatisch toe zodra een gefedereerde share succesvol gecreëerd is",
     "Trusted servers" : "Vertrouwde servers",
+    "Add server automatically once a federated share was created successfully" : "Voeg server automatisch toe zodra een gefedereerde share succesvol gecreëerd is",
     "+ Add trusted server" : "+ Toevoegen vertrouwde server",
     "Trusted server" : "Vertrouwde server",
-    "Add" : "Toevoegen",
-    "Trusted Servers" : "Vertrouwde servers",
-    "+ Add Nextcloud server" : "+ Toevoegen Nextcloud server",
-    "Nextcloud Server" : "Nextcloud Server",
-    "Server added to the list of trusted Nextclouds" : "Server toegevoegd aan de lijst met vertrouwde Nextclouds",
-    "No Nextcloud server found" : "Geen Nextcloud server gevonden",
-    "Nextcloud Federation allows you to connect with other trusted Nextclouds to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Nextcloud federatie maakt het mogelijk om te verbinden met andere vertrouwde Nextclouds om de gebuikersadministratie te delen. Zo kun je automatisch externe gebruikers toevoegen voor federatief delen.",
-    "Trusted Nextcloud Servers" : "Vertrouwde Nextcloud Servers"
+    "Add" : "Toevoegen"
 },
 "nplurals=2; plural=(n != 1);");
