@@ -8,6 +8,10 @@
  *
  */
 
+var isSecureViewerAvailable = function () {
+	return $('#hideDownload').val() === 'true' && typeof OCA.RichDocuments !== 'undefined';
+};
+
 (function(OCA) {
 
 	OCA.FilesPdfViewer = OCA.FilesPdfViewer || {};
@@ -42,14 +46,15 @@
 
 		/**
 		 * @param downloadUrl
+		 * @param param
 		 * @param isFileList
 		 */
-		show: function(downloadUrl, isFileList) {
+		show: function(downloadUrl, param, isFileList) {
 			var self = this;
 			var shown = true;
 			var $iframe;
 			var viewer = OC.generateUrl('/apps/files_pdfviewer/?file={file}', {file: downloadUrl});
-			$iframe = $('<iframe id="pdframe" style="width:100%;height:100%;display:block;position:absolute;top:0;z-index:1041;left:0;" src="'+viewer+'" sandbox="allow-scripts allow-same-origin allow-popups allow-modals allow-top-navigation" allowfullscreen="true"/>');
+			$iframe = $('<iframe id="pdframe" style="width:100%;height:100%;display:block;position:absolute;top:0;z-index:1041;left:0;" src="'+viewer+param+'" sandbox="allow-scripts allow-same-origin allow-popups allow-modals allow-top-navigation" allowfullscreen="true"/>');
 
 			if(isFileList === true) {
 				FileList.setViewerMode(true);
@@ -76,6 +81,10 @@
 			// if a filelist is present, the PDF viewer can be closed to go back there
 			$('#pdframe').load(function(){
 				var iframe = $('#pdframe').contents();
+				if ($('#hideDownload').val() === 'true') {
+					iframe.find('.toolbarButton.download').hide()
+					iframe.find('.toolbarButton.print').hide()
+				}
 				if ($('#fileList').length)
 				{
 					iframe.find('#secondaryToolbarClose').click(function() {
@@ -116,6 +125,9 @@
 		 */
 		_extendFileActions: function(fileActions) {
 			var self = this;
+			if (isSecureViewerAvailable()) {
+				return;
+			}
 			fileActions.registerAction({
 				name: 'view',
 				displayName: 'Favorite',
@@ -124,7 +136,7 @@
 				actionHandler: function(fileName, context) {
 					var downloadUrl = context.fileList.getDownloadUrl(fileName, context.dir);
 					if (downloadUrl && downloadUrl !== '#') {
-						self.show(downloadUrl, true);
+						self.show(downloadUrl, '', true);
 					}
 				}
 			});
@@ -138,11 +150,19 @@ OC.Plugins.register('OCA.Files.FileList', OCA.FilesPdfViewer.PreviewPlugin);
 
 // FIXME: Hack for single public file view since it is not attached to the fileslist
 $(document).ready(function(){
-	if ($('#isPublic').val() && $('#mimetype').val() === 'application/pdf') {
+	if ($('#isPublic').val() && $('#mimetype').val() === 'application/pdf' && !isSecureViewerAvailable()) {
+		$.urlParam = function(name){
+			var results = new RegExp('[\?&]' + name + '=([^&#]*)').exec(window.location.href);
+			if (results == null) {
+				return 0;
+			}
+			return results[1] || 0;
+		};
 		var sharingToken = $('#sharingToken').val();
+		var page = '#page='+$.urlParam('page');
 		var downloadUrl = OC.generateUrl('/s/{token}/download', {token: sharingToken});
 		var viewer = OCA.FilesPdfViewer.PreviewPlugin;
-		viewer.show(downloadUrl, false);
+		viewer.show(downloadUrl, page, false);
 	}
 });
 
