@@ -8,28 +8,32 @@ OC.L10N.register(
     "Name cannot be empty" : "Je třeba zadat název",
     "The given name is too long" : "Zadaný název je příliš dlouhý",
     "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
+    "The given web address is not a valid URL" : "Zadaná webová adresa není platná URL",
     "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
+    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platnou URL adresou",
     "The given privacy policy address is too long" : "Daná adresa zásad ochrany osobních údajů je příliš dlouhá",
+    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platná URL adresa",
     "The given slogan is too long" : "Zadaný slogan je příliš dlouhý",
     "The given color is invalid" : "Zadaná barva není platná",
     "The file was uploaded" : "Soubor byl nahrán",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahrávaný soubor přesahuje nastavení upload_max_filesize v php.ini",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahraný soubor překračuje nastavení MAX_FILE_SIZE, která byla zadána ve HTML formuláři",
     "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
     "No file was uploaded" : "Nebyl nahrán žádný soubor",
     "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
-    "Could not write file to disk" : "Nedaří se zapsat na datové úložiště",
+    "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
     "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
     "No file uploaded" : "Nenahrán žádný soubor",
     "Unsupported image type" : "Nepodporovaný typ obrázku",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
-    "Theming" : "Motivy",
+    "Theming" : "Motiv vzhledu",
     "Legal notice" : "Právní upozornění",
-    "Privacy policy" : "Zásady soukromí",
+    "Privacy policy" : "Zásady ochrany soukromí",
     "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduché přizpůsobení vzhledu vaší instance a podporovaných klientů. Tato přizpůsobení uvidí všichni uživatelé.",
+    "Open documentation" : "Otevřít dokumentaci",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
     "Name" : "Název",
-    "Reset to default" : "Obnovit výchozí",
+    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
     "Web link" : "Webový odkaz",
     "https://…" : "https://…",
     "Slogan" : "Slogan",
@@ -43,17 +47,9 @@ OC.L10N.register(
     "Legal notice link" : "Odkaz na právní upozornění",
     "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
     "Header logo" : "Logo v záhlaví",
-    "Upload new header logo" : "Nahrát nové logo do hlavičky",
-    "Favicon" : "Favicon",
+    "Upload new header logo" : "Nahrát nové logo do záhlaví",
+    "Favicon" : "ikona webu",
     "Upload new favicon" : "Nahrát novou ikonu webu",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky generuje favicony na základě nahraného loga a barvy.",
-    "You are already using a custom theme" : "Již používáte vlastní motiv",
-    "reset to default" : "obnovit výchozí",
-    "Web address" : "Webová adresa",
-    "Web address https://…" : "Webová adresa https://",
-    "There is no error, the file uploaded with success" : "Nenastala žádná chyba, soubor byl úspěšně nahrán",
-    "The uploaded file was only partially uploaded" : "Soubor byl nahrán pouze částečně",
-    "Failed to write file to disk." : "Zápis na disk se nezdařil.",
-    "A PHP extension stopped the file upload." : "Rozšíření PHP zastavilo nahrávání souboru."
+    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky generuje favicony na základě nahraného loga a barvy."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
