@@ -3,9 +3,9 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "Nem írható a \"config\" könyvtár!",
     "This can usually be fixed by giving the webserver write access to the config directory" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Avagy, ha jobbnak tűnik tarthatod a config.php fájlt olvashatónak, csak engedélyezd a \"config_is_read_only\" kapcsolót.",
     "See %s" : "Lásd %s",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra. Lásd: %s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "%$1s alkalmazás fájljai nem megfelelően lettek cserélve. Győződj meg róla, hogy ez a verzió kompatibilis-e a szerverrel.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Avagy, ha jobbnak tűnik tarthatod a config.php fájlt olvashatónak, csak engedélyezd a \"config_is_read_only\" kapcsolót. Továbbiak itt:%s",
     "Sample configuration detected" : "A példabeállítások vannak beállítva",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik a példakonfigurációt próbálja ténylegesen használni. Ez nem támogatott, és működésképtelenné teheti a telepítést. Kérlek olvasd el a dokumentációt és azt követően változtas a config.php-n!",
     "%1$s and %2$s" : "%1$s és %2$s",
@@ -22,10 +22,13 @@ OC.L10N.register(
     "Following databases are supported: %s" : "A következő adatbázisok támogatottak: %s",
     "The command line tool %s could not be found" : "A parancssori eszköz nem található: %s",
     "The library %s is not available." : "A könyvtár %s nem áll rendelkezésre.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$s könyvtár %2$s vagy újabb verziója szükséges - elérhető verzió: %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s könyvtár %2$s vagy régebbi verziója szükséges - elérhető verzió: %3$s.",
     "Following platforms are supported: %s" : "Ezek a platformok támogatottak: %s",
     "Server version %s or higher is required." : "%s vagy újabb szerver verzió szükséges.",
     "Server version %s or lower is required." : "%s vagy régebbi szerver verzió szükséges.",
     "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
+    "Authentication" : "Hitelesítés",
     "Unknown filetype" : "Ismeretlen fájl típus",
     "Invalid image" : "Hibás kép",
     "Avatar image is not square" : "Az avatár kép nem négyzetes.",
@@ -64,27 +67,15 @@ OC.L10N.register(
     "Log out" : "Kijelentkezés",
     "Users" : "Felhasználók",
     "Unknown user" : "Ismeretlen felhasználó",
-    "Create" : "Létrehozás",
-    "Change" : "Változtatás",
-    "Delete" : "Törlés",
-    "Share" : "Megosztás",
-    "Basic settings" : "Alapvető beállítások",
-    "Sharing" : "Megosztás",
-    "Security" : "Biztonság",
     "Additional settings" : "További beállítások",
-    "Personal info" : "Személyes információk",
-    "Unlimited" : "Korlátlan",
-    "Verifying" : "Ellenőrzés",
-    "Verifying …" : "Ellenőrzés...",
-    "Verify" : "Ellenőrzés",
     "%s enter the database username and name." : "%s add meg az adatbázis nevét és felhasználónevét",
     "%s enter the database username." : "%s adja meg az adatbázist elérő felhasználó login nevét.",
     "%s enter the database name." : "%s adja meg az adatbázis nevét.",
     "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
+    "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnod.",
     "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
     "Oracle username and/or password not valid" : "Az Oracle felhasználói név és/vagy jelszó érvénytelen",
     "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név és/vagy jelszó érvénytelen",
-    "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnod.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Csak saját felelősségre használja!",
     "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux-alapú szervert használni.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32-bites PHP környezetben fut és az open_basedir konfigurálva van a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat így erősen ellenjavallt.",
@@ -93,27 +84,22 @@ OC.L10N.register(
     "Set an admin password." : "Állítson be egy rendszergazdai jelszót!",
     "Can't create or write into the data directory %s" : "Nem sikerült  létrehozni vagy irni  a \"data\" könyvtárba %s",
     "Invalid Federated Cloud ID" : "Érvénytelen Egyesített Felhő Azonosító",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s megosztása sikertelen, mert a megosztási alrendszer nem engedi a %l típus megosztását",
-    "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
-    "You are not allowed to share %s" : "Nincs jogosultságod %s megosztására",
-    "Sharing %s failed, because you can not share with yourself" : "%s megosztása sikertelen, mert magaddal nem oszthatod meg",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános hivatkozások csak jelszóval védetten használhatók",
-    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a hivatkozással történő megosztás nincs engedélyezve",
-    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet létrehozni egyesített megosztást.",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
-    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Az %s megosztási alrendszernek támogatnia kell az OCP\\Share_Backend interface-t",
     "Sharing backend %s not found" : "A %s megosztási alrendszer nem található",
     "Sharing backend for %s not found" : "%s megosztási alrendszere nem található",
-    "Sharing failed, because the user %s is the original sharer" : "Megosztás sikertelen, mert %s felhasználó az eredeti megosztó",
-    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s megosztotta veled »%2$s« és hozzá akarja adni:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s megosztotta veled »%2$s« és hozzá akarja adni",
+    "»%s« added a note to a file shared with you" : "»%s« megjegyést fűzött a veled megosztott fájlhoz",
     "Open »%s«" : "»%s« megnyitása",
+    "%1$s via %2$s" : "%1$s - %2$s",
+    "You are not allowed to share %s" : "Nincs jogosultságod %s megosztására",
     "Can’t increase permissions of %s" : "A(z) %s engedélyei nem kibővíthetők",
     "Files can’t be shared with delete permissions" : "A fájlok nem megoszthatók törlési joggal",
     "Files can’t be shared with create permissions" : "Fájlok nem oszthatók meg létrehozási joggal",
     "Expiration date is in the past" : "A lejárati dátum már elmúlt",
     "Can’t set expiration date more than %s days in the future" : "Nem lehet  %s napnál későbbi lejáratot megadni",
+    "%1$s shared »%2$s« with you" : "%1$s megosztotta veled »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s megosztotta veled »%2$s«.",
     "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
     "The requested share does not exist anymore" : "A kért megosztás már nem létezik",
     "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
@@ -171,6 +157,7 @@ OC.L10N.register(
     "Could not create user" : "Nem sikerült létrehozni a felhasználót",
     "User disabled" : "Felhasználó letiltva",
     "Login canceled by app" : "Bejelentkezés megszakítva az alkalmazás által",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" alkalmazást nem lehet telepíteni, mert a következő függőségek nem teljesülnek: %2$s",
     "a safe home for all your data" : "egy biztonságos hely az adataidnak",
     "File is currently busy, please try again later" : "A fájl jelenleg elfoglalt, kérjük próbáld újra később!",
     "Can't read file" : "Nem olvasható a fájl",
@@ -179,8 +166,8 @@ OC.L10N.register(
     "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nincs telepítve adatbázis-meghajtóprogram (sqlite, mysql vagy postgresql).",
     "Cannot write into \"config\" directory" : "Nem írható a \"config\" könyvtár",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra. Lásd: %s",
     "Cannot write into \"apps\" directory" : "Nem írható az \"apps\" könyvtár",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ez legtöbbször megoldható az app mappára a webszervernek adott írási joggal, vagy a config fájlban az alkalmazástár letiltásával. Lásd: %s",
     "Cannot create \"data\" directory" : "\"data\" mappa nem hozható létre",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ez legtöbbször megoldható a gyökér mappára a webszervernek adott írási joggal. Lásd: %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Ez legtöbbször megoldható a gyökér mappára a webszervernek adott írási joggal. Lásd:  %s.",
@@ -206,46 +193,53 @@ OC.L10N.register(
     "Check the value of \"datadirectory\" in your configuration" : "Ellenőrizd a \"datadirectory\" értékét a konfigurációban",
     "Your data directory is invalid" : "Az adatkönyvtárad érvénytelen",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Győződj meg róla, hogy az adatmappa gyökerében legyen egy \".ocdata\" nevű fájl",
+    "Action \"%s\" not supported or implemented." : "\"%s\" művelet nem támogatott vagy nem ismert.",
+    "Authentication failed, wrong token or provider ID given" : "Azonosítás sikertelen, hibás token vagy szolgáltató lett megadva",
+    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "A következő paraméterek hiányoznak, hogy végrehajtható legyen a kérés. Paraméterek: \"%s\"",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" már hasznalatban van a Felhő szolgáltatónál: \"%2$s\"",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" ID nem létezik a Felhő szolgáltatónal.",
     "Could not obtain lock type %d on \"%s\"." : "Nem sikerült %d típusú zárolást elérni itt: \"%s\".",
     "Storage unauthorized. %s" : "A tároló jogosulatlan. %s",
     "Storage incomplete configuration. %s" : "A tároló beállítása nem teljes. %s",
     "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
     "Storage is temporarily not available" : "A tároló átmenetileg nem érthető el",
     "Storage connection timeout. %s" : "Tároló kapcsolat időtúllépés. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "%s könyvtár %s vagy újabb verziója szükséges - elérhető verzió: %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "%s könyvtár %s vagy régebbi verziója szükséges - elérhető verzió: %s.",
-    "Personal" : "Személyes",
-    "Admin" : "Rendszergazda",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "Titkosítás",
-    "Tips & tricks" : "Tippek és trükkök",
-    "DB Error: \"%s\"" : "Adatbázis hiba: \"%s\"",
-    "Offending command was: \"%s\"" : "A hibát ez a parancs okozta: \"%s\"",
-    "Offending command was: \"%s\", name: %s, password: %s" : "A hibát okozó parancs ez volt: \"%s\", login név: %s, jelszó: %s",
-    "Sharing %s failed, because the user %s does not exist" : "%s megosztása nem sikerült, mert %s felhasználó nem létezik",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja egyik olyan csoportnak sem, aminek %s tagja",
-    "Sharing %s failed, because this item is already shared with %s" : "%s megosztása nem sikerült, mert ez már meg van osztva %s-vel",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s megosztása sikertelen, mert már meg van osztva %s felhasználóval",
-    "Sharing %s failed, because the group %s does not exist" : "%s megosztása nem sikerült, mert %s csoport nem létezik",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja a %s csoportnak",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s megosztása sikertelen, mert %s nem található, talán a szerver jelenleg nem elérhető.",
-    "Share type %s is not valid for %s" : "A %s megosztási típus nem érvényes %s-re",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a megadottak túllépik a %s-re érvényes jogosultságokat",
-    "Setting permissions for %s failed, because the item was not found" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a kérdéses fájl nem található",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Nem lehet beállítani a lejárati időt. A megosztásoknak kötelező megadni lejárati időt!",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %s rendelkezésére áll",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s megosztása nem sikerült, mert %s megosztási alrendszere nem találja",
-    "Cannot increase permissions of %s" : "%s jogosultságait nem lehet megemelni",
-    "Files can't be shared with delete permissions" : "A fájlokat nem lehet megosztani a törlési jogosultságokkal",
-    "Files can't be shared with create permissions" : "A fájlokat nem lehet megosztani a létrehozási jogosultságokkal",
-    "Cannot set expiration date more than %s days in the future" : "%s napnál távolabbi lejárati dátumot nem lehet beállítani",
-    "%s shared »%s« with you" : "%s megosztotta veled ezt:  »%s«",
-    "%s shared »%s« with you." : "%s megosztotta »%s«-t veled.",
-    "%s via %s" : "%s - %s",
-    "No app name specified" : "Nincs az alkalmazás név megadva.",
-    "App '%s' could not be installed!" : "\"%s\" alkalmazás nem lehet telepíthető!",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "\"%s\" alkalmazás nem lehet telepíteni, mert a következő függőségek nincsenek kielégítve: %s",
-    "Sync clients" : "Szinkronizálási kliensek"
+    "Create" : "Létrehozás",
+    "Change" : "Változtatás",
+    "Delete" : "Törlés",
+    "Share" : "Megosztás",
+    "Overview" : "Áttekintés",
+    "Basic settings" : "Alapvető beállítások",
+    "Sharing" : "Megosztás",
+    "Security" : "Biztonság",
+    "Groupware" : "Csoportmunka",
+    "Personal info" : "Személyes információk",
+    "Mobile & desktop" : "Mobil és deszktop",
+    "Unlimited" : "Korlátlan",
+    "Verifying" : "Ellenőrzés",
+    "Verifying …" : "Ellenőrzés...",
+    "Verify" : "Ellenőrzés",
+    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s megosztása sikertelen, mert a megosztási alrendszer nem engedi a %l típus megosztását",
+    "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
+    "Sharing %s failed, because you can not share with yourself" : "%s megosztása sikertelen, mert magaddal nem oszthatod meg",
+    "Sharing %1$s failed, because the user %2$s does not exist" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem létezik",
+    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem tagja egyik olyan csoportnak sem, aminek %3$s tagja",
+    "Sharing %1$s failed, because this item is already shared with %2$s" : "%1$s megosztása nem sikerült, mert ez már meg van osztva vele: %2$s",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
+    "Sharing %1$s failed, because the group %2$s does not exist" : "%1$s megosztása nem sikerült, mert %2$s csoport nem létezik",
+    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem tagja a %3$s csoportnak",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános hivatkozások csak jelszóval védetten használhatók",
+    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a hivatkozással történő megosztás nincs engedélyezve",
+    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet létrehozni egyesített megosztást.",
+    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "%1$s megosztása sikertelen, mert %2$s nem található; talán a szerver jelenleg nem elérhető.",
+    "Share type %1$s is not valid for %2$s" : "A %1$s megosztási típus nem érvényes %2$s-re",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
+    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
+    "Sharing failed, because the user %s is the original sharer" : "Megosztás sikertelen, mert %s felhasználó az eredeti megosztó",
+    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "%1$s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %2$s rendelkezésére áll",
+    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "%1$s megosztása nem sikerült, mert %2$s megosztási alrendszere nem találja",
+    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ez legtöbbször megoldható az app mappára a webszervernek adott írási joggal, vagy a config fájlban az alkalmazástár letiltásával. Lásd: %s"
 },
 "nplurals=2; plural=(n != 1);");
